@@ -26,7 +26,8 @@
 use strict;
 use diagnostics;
 use Data::Dumper;
-use RundeckAPI;
+use lib "../lib";
+use RundeckAPI 1.1;
 
 #####
 ## PROTOS
@@ -48,13 +49,14 @@ my $rc=0;
 my $api = RundeckAPI->new(
 		'url'		=> "https://rundeck.company.com:4440",
 		'login'		=> "admin",
-		'token'		=> '<Token from GUI, as admin>',
+		'password'	=> "admin",
+### OR
+#		'token'		=> '<Token from GUI, as admin>'
 		'debug'		=> 1,
-		'apivers'	=> '42',
  		'proxy'		=> "http://proxy.your.company:3128",
 );
 
-my $hashRef = $api->get("system/info");
+my $hashRef = $api->get("/api/27/system/info");
 
 print Dumper($hashRef);
 
